@@ -1,9 +1,9 @@
 package App::ProveRdeps;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-01-30'; # DATE
+our $DATE = '2020-01-31'; # DATE
 our $DIST = 'App-ProveRdeps'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -200,7 +200,7 @@ is searched. If not found, then the name with different case (e.g.
 `p5-My-Perl-Dist` or `cpan-My-Perl-Dist`) is searched. If not found, a prefix
 match (e.g. `My-Perl-Dist-perl`) is searched. If not found, *prove-rdeps* will
 try to download the distribution tarball from local CPAN mirror and extract it
-to a temporary directory. If `--no-dowload` is given, the *prove-deps* will not
+to a temporary directory. If `--no-dowload` is given, the *prove-rdeps* will not
 download from local CPAN mirror and give up for that distribution.
 
 When a dependent distribution cannot be found or downloaded/extracted, this
@@ -209,7 +209,7 @@ counts as a 412 error (Precondition Failed).
 When a distribution's test fails, this counts as a 500 error (Error). Otherwise,
 the status is 200 (OK).
 
-*prove-deps* will return status 200 (OK) with the status of each dist. It will
+*prove-rdeps* will return status 200 (OK) with the status of each dist. It will
 exit 0 if all distros are successful, otherwise it will exit 1.
 
 _
@@ -405,7 +405,7 @@ App::ProveRdeps - Prove all distributions depending on specified module(s)
 
 =head1 VERSION
 
-This document describes version 0.006 of App::ProveRdeps (from Perl distribution App-ProveRdeps), released on 2020-01-30.
+This document describes version 0.007 of App::ProveRdeps (from Perl distribution App-ProveRdeps), released on 2020-01-31.
 
 =head1 SYNOPSIS
 
@@ -490,7 +490,7 @@ C<my-perl-dist>) is searched. If not found, a suffix match (e.g.
 C<p5-My-Perl-Dist> or C<cpan-My-Perl-Dist>) is searched. If not found, a prefix
 match (e.g. C<My-Perl-Dist-perl>) is searched. If not found, I<prove-rdeps> will
 try to download the distribution tarball from local CPAN mirror and extract it
-to a temporary directory. If C<--no-dowload> is given, the I<prove-deps> will not
+to a temporary directory. If C<--no-dowload> is given, the I<prove-rdeps> will not
 download from local CPAN mirror and give up for that distribution.
 
 When a dependent distribution cannot be found or downloaded/extracted, this
@@ -499,7 +499,7 @@ counts as a 412 error (Precondition Failed).
 When a distribution's test fails, this counts as a 500 error (Error). Otherwise,
 the status is 200 (OK).
 
-I<prove-deps> will return status 200 (OK) with the status of each dist. It will
+I<prove-rdeps> will return status 200 (OK) with the status of each dist. It will
 exit 0 if all distros are successful, otherwise it will exit 1.
 
 This function is not exported.
